@@ -7,7 +7,8 @@ This python based project helps you to extract and analyze data related to brazi
 """
 
 #modules from the python standard library
-import os, os.path
+import os
+import os.path
 import zipfile
 import datetime
 import calendar
@@ -15,6 +16,7 @@ import sqlite3
 
 #packages used to download data
 import requests
+from requests import HTTPError
 from yahoofinancials import YahooFinancials
 
 #packages used to manipulate data
@@ -38,25 +40,25 @@ def cvm_informes (year: int, mth: int) -> pd.DataFrame:
 
    """
 
-    if int(year) >= 2017: #utiliza a estrutura de download para dados a partir de 2017
+    if int(year) >= 2017: #uses download process from reports after the year of 2017
         try:
             mth = f"{mth:02d}"
             year = str(year)
-            #criamos a url a partis dos parametros passados para a funcao
+            #creates url using the parameters provided to the function
             url = 'http://dados.cvm.gov.br/dados/FI/DOC/INF_DIARIO/DADOS/inf_diario_fi_'+year+mth+'.csv'
             
-            #lemos o arquivo csv retornado pelo link
+            #reads the csv returned by the link
             cotas = pd.read_csv(url, sep =';')
-            cotas['DT_COMPTC'] = pd.to_datetime(cotas['DT_COMPTC']) #define tipo datetime para coluna de data
+            cotas['DT_COMPTC'] = pd.to_datetime(cotas['DT_COMPTC']) #casts date column to datetime
             
             try:
-                #remove coluna que aparece apenas em certos arquivos para evitar inconsistencias
+                #removes column present in only a few reports to avoid inconsistency when making the union of reports
                 cotas.drop(columns = ['TP_FUNDO'], inplace = True)
-            except:
+            except KeyError:
                 pass
             
             return cotas
-        except:
+        except HTTPError:
             print('theres no report for this date yet!.\n')
     
     if int(year) < 2017:
@@ -64,22 +66,22 @@ def cvm_informes (year: int, mth: int) -> pd.DataFrame:
             year = str(year)
 
             url = 'http://dados.cvm.gov.br/dados/FI/DOC/INF_DIARIO/DADOS/HIST/inf_diario_fi_' + year + '.zip'
-            #envia requests para a url
-            r = requests.get(url, stream=True, verify=False, allow_redirects=True)
+            #sends request to the url
+            r = requests.get(url, stream=True, allow_redirects=True)
             
-            with open('informe' + year + '.zip', 'wb') as fd: #salva arquivo .zip
+            with open('informe' + year + '.zip', 'wb') as fd: #writes the .zip file downloaded
                 fd.write(r.content)
 
-            zip_inf = zipfile.ZipFile('informe' + year + '.zip') #abre arquivo .zip
+            zip_inf = zipfile.ZipFile('informe' + year + '.zip') #opens the .zip file
             
             #le os arquivos csv dentro do arquivo zip
             informes = [pd.read_csv(zip_inf.open(f), sep=";") for f in zip_inf.namelist()] 
             cotas = pd.concat(informes,ignore_index=True)
             
-            cotas['DT_COMPTC'] = pd.to_datetime(cotas['DT_COMPTC']) #define tipo datetime para coluna de data
+            cotas['DT_COMPTC'] = pd.to_datetime(cotas['DT_COMPTC']) #casts date column to datetime
 
             zip_inf.close() #fecha o arquivo zip
-            os.remove('informe' + year + '.zip') #apaga o arquivo zip
+            os.remove('informe' + year + '.zip') #deletes .zip file
             
             return cotas
         
@@ -121,7 +123,7 @@ def start_db(db_dir: str = 'investments_database.db', start_year: int = 2005, ta
                         informe = informe[informe.CNPJ_FUNDO.isin(target_funds)]
                     #appends information to the sql database
                     informe.to_sql('daily_quotas', con , if_exists = 'append', index=False)
-                except:
+                except AttributeError:
                     pass
             
             elif year<2017: #loop structure to handle years before 2017 (they have a different file structure)
@@ -134,7 +136,7 @@ def start_db(db_dir: str = 'investments_database.db', start_year: int = 2005, ta
                             informe = informe[informe.CNPJ_FUNDO.isin(target_funds)]
                         #appends information to the sql database
                         informe.to_sql('daily_quotas', con , if_exists = 'append', index=False)
-                    except:
+                    except AttributeError:
                         pass
 
     #pushes target funds to sql for use when updating the database
@@ -247,18 +249,14 @@ def update_db(db_dir: str = r'investments_database.db'):
     print('deleting redundant data from the database... \n')
     tables = {'daily_quotas' : ['DT_COMPTC',last_quota.strftime("%Y-%m-01")],
               'ibov_returns' : ['Date',last_update.strftime("%Y-%m-%d")]}
-    for i in tables:
-        #sql delete statement to the database
-        delete = f'''
-        delete
-        from {i}
-        where {tables[i][0]} >= "{tables[i][1]}"
-        '''
-        
-        cursor = con.cursor()
-        cursor.execute(delete)
-        con.commit()
+    
+    cursor = con.cursor()
+    
+    #sql delete statement to the database
+    cursor.execute('delete from daily_quotas where DT_COMPTC >= :date', {'date': last_quota.strftime("%Y-%m-01")})
+    cursor.execute('delete from ibov_returns where Date >= :date', {'date': last_update.strftime("%Y-%m-%d")})
         
+    con.commit()  
     cursor.close()
 
 
@@ -268,7 +266,7 @@ def update_db(db_dir: str = r'investments_database.db'):
 
     try:#tries to read targets funds if they were specified when starting the database
         target_funds = pd.read_sql('select targets from target_funds', con).targets.to_list()
-    except:
+    except AttributeError:
         target_funds = []
     
     print('downloading new daily reports from the CVM website...\n')
@@ -280,7 +278,7 @@ def update_db(db_dir: str = r'investments_database.db'):
             informe = informe[informe.CNPJ_FUNDO.isin(target_funds)]
         try:
             informe.to_sql('daily_quotas', con , if_exists = 'append', index=False)
-        except:
+        except AttributeError:
             pass 
 
     #downloads cadastral information from CVM of the fundos and pushes it to the database
@@ -313,16 +311,12 @@ def update_db(db_dir: str = r'investments_database.db'):
 
     #updates ibovespa data
     print('updating ibovespa returns...\n')
-    try:
-        today = (datetime.date.today() + datetime.timedelta(1)).strftime('%Y-%m-%d')
-        ibov = pd.DataFrame(YahooFinancials('^BVSP').get_historical_price_data(last_update.strftime('%Y-%m-%d'), today, 'daily')['^BVSP']['prices'])
-        ibov = ibov.drop(columns=['date', 'close']).rename(columns={'formatted_date':'date', 'adjclose':'close'}).iloc[:,[5,0,1,2,3,4]]
-        ibov['date'] = pd.to_datetime(ibov['date'])
-        ibov.columns = [i.capitalize() for i in ibov.columns] #capitalizes columns to keep consistency with previous format (investpy)
-        ibov.to_sql('ibov_returns', con , if_exists = 'append', index=False)
-    except:
-        pass
-
+    today = (datetime.date.today() + datetime.timedelta(1)).strftime('%Y-%m-%d')
+    ibov = pd.DataFrame(YahooFinancials('^BVSP').get_historical_price_data(last_update.strftime('%Y-%m-%d'), today, 'daily')['^BVSP']['prices'])
+    ibov = ibov.drop(columns=['date', 'close']).rename(columns={'formatted_date':'date', 'adjclose':'close'}).iloc[:,[5,0,1,2,3,4]]
+    ibov['date'] = pd.to_datetime(ibov['date'])
+    ibov.columns = [i.capitalize() for i in ibov.columns] #capitalizes columns to keep consistency with previous format (investpy)
+    ibov.to_sql('ibov_returns', con , if_exists = 'append', index=False)
 
     ##STEP 5
     #updates the log in the database
@@ -353,7 +347,7 @@ def returns(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_QUO
     pd.DataFrame: If rolling = True: Pandas dataframe with total % returns for the assets. If rolling = False: The original pandas dataframe with added columns for the % returns in the rolling windows.
 
    """
-    if rolling == False:
+    if not rolling:
         window_size = 1
 
     #garantees that the values are positive, once division by zero returns infinite
@@ -370,13 +364,13 @@ def returns(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_QUO
     returns.columns = col_names
 
     #if the parameter rolling = False, returns the original data with the added rolling returns
-    if rolling == True:
+    if rolling:
         df2 = df.merge(returns, how='left', left_index=True, right_index=True)
         return df2
 
     #if the parameter rolling = True, returns the total compound returns in the period, the number of days
     # and the Compound Annual Growth Rate (CAGR)
-    elif rolling == False: 
+    if not rolling: 
         returns = df[[group]].merge(returns, left_index = True, right_index = True)
         
         #calculates the compound returns
@@ -400,8 +394,7 @@ def returns(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_QUO
 
         return returns                                   
 
-    else: 
-        raise Exception("Wrong Parameter: rolling can only be True or False.") 
+    raise Exception("Wrong Parameter: rolling can only be True or False.") 
         
 
 def cum_returns(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_QUOTA']) -> pd.DataFrame:
@@ -444,7 +437,7 @@ def volatility(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_
     pd.DataFrame: If rolling = False: Pandas dataframe with total volatility for the assets. If rolling = True: The original pandas dataframe with added columns for the volatility in the rolling windows.
 
    """
-    if rolling == False:
+    if not rolling:
         vol = df.copy(deep=True)
         for col in values:
             vol = df[df[col].notnull()]
@@ -460,7 +453,7 @@ def volatility(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_
         
         return vol
 
-    elif rolling == True: 
+    if rolling: 
         vol = df.copy(deep=True)
         for col in values:
             vol = df[df[col].notnull()]
@@ -482,8 +475,7 @@ def volatility(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_
         df2 = df.merge(vol.drop(columns = group),left_index=True,right_index=True)
         return df2
     
-    else: 
-        raise Exception("Wrong Parameter: rolling can only be True or False.")
+    raise Exception("Wrong Parameter: rolling can only be True or False.")
   
 
 def drawdown(df: pd.DataFrame, group: str = 'CNPJ_FUNDO', values: list = ['VL_QUOTA'])-> pd.DataFrame:
@@ -521,7 +513,7 @@ def corr_benchmark(df: pd.DataFrame,  asset_returns: str, index_returns: str, gr
     pd.DataFrame: If rolling = False: Pandas dataframe with total correlation for the assets and their benchmarks. If rolling = True: The original pandas dataframe with an added column for the correlation in the rolling windows.
 
    """
-    if rolling == False: 
+    if not rolling: 
         #calculates the correlation between assests returns for the whole period
         corr = df[df[asset_returns].notnull()].groupby([group])[[asset_returns,index_returns]].corr()
         corr = corr.xs(index_returns,level = 1, drop_level=False)
@@ -529,7 +521,7 @@ def corr_benchmark(df: pd.DataFrame,  asset_returns: str, index_returns: str, gr
         corr = corr.drop(columns=[index_returns])
         corr.columns=['correlation_benchmark']
         return corr
-    elif rolling == True:  
+    if rolling:  
         #calculates the correlation between the assests returns across rolling windows     
         corr = (df[df[asset_returns].notnull()].groupby(group)[[asset_returns,index_returns]]
                                               .rolling(window_size)
@@ -541,8 +533,8 @@ def corr_benchmark(df: pd.DataFrame,  asset_returns: str, index_returns: str, gr
                 )
         df2 = df.merge(corr.drop(columns = [group]),left_index=True,right_index=True)
         return df2
-    else:
-        raise Exception("Wrong Parameter: rolling can only be True or False") 
+    
+    raise Exception("Wrong Parameter: rolling can only be True or False") 
 
 
 def beta(df: pd.DataFrame, asset_vol: str, bench_vol: str, correlation: str = 'correlation_benchmark') -> pd.DataFrame:
@@ -641,7 +633,7 @@ def capture_ratio(df: pd.DataFrame, asset_returns: str, bench_returns: str, retu
     df_bear = df_bear[df_bear[bench_returns] <= 0] #dataframe with only negative returns from the benchmark
 
     tables = [df_bull, df_bear]
-    for i in range(len(tables)): #performs set of operations in each table
+    for i, _ in enumerate(tables): #performs set of operations in each table
         #calculates total returns + 1
         compound = tables[i].groupby(group)[[asset_returns,bench_returns]].apply(lambda x: np.prod(1+x))
         
